@@ -45,11 +45,11 @@ void HLCmdLineApp::printVersionInfo()
 {
     cout << "\n highlight version "
          << HIGHLIGHT_VERSION
-         << "\n Copyright (C) 2002-2016 Andre Simon <andre.simon1 at gmx.de>"
+         << "\n Copyright (C) 2002-2017 Andre Simon <andre.simon1 at gmx.de>"
          << "\n\n Argparser class"
          << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
-         << "\n\n Artistic Style Classes (2.05)"
-         << "\n Copyright (C) 2006-2014 by Jim Pattee <jimp03 at email.com>"
+         << "\n\n Artistic Style Classes (2.06)"
+         << "\n Copyright (C) 2006-2016 by Jim Pattee <jimp03 at email.com>"
          << "\n Copyright (C) 1998-2002 by Tal Davidson"
          << "\n\n Diluculum Lua wrapper (1.0)"
          << "\n Copyright (C) 2005-2013 by Leandro Motta Barros"
@@ -479,7 +479,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             cerr << "highlight: output format supports no external styles.\n";
             return EXIT_FAILURE;
         }
-        bool useStdout =  options.getStyleOutFilename() =="stdout";
+        bool useStdout =  options.getStyleOutFilename() =="stdout" || options.forceStdout();
         string cssOutFile=options.getOutDirectory()  + options.getStyleOutFilename();
         bool success=generator->printExternalStyle ( useStdout?"":cssOutFile );
         if ( !success ) {
@@ -561,7 +561,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                 break;
             } else if ( loadRes==highlight::LOAD_FAILED ) {
                 // do also ignore error msg if --syntax parameter should be skipped
-                if ( ! (options.quietMode() || options.isSkippedExt ( suffix )) ) {
+                if ( ! (options.forceOutput() || options.quietMode() || options.isSkippedExt ( suffix )) ) {
                     cerr << "highlight: Unknown source file extension \""
                          << suffix
                          << "\". Consider the "
@@ -584,32 +584,32 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
         if ( options.enableBatchMode() ) {
             if (usedFileNames.count(inFileName)) {
-                string prefix=inFileList[i].substr (0, pos+1 );
+                string prefix=inFileList[i].substr (2, pos-1 );
                 replace (prefix.begin(), prefix.end(), Platform::pathSeparator, '_');
                 inFileName.insert(0, prefix);
             } else {
                 usedFileNames.insert(inFileName);
             }
-            outFilePath = outDirectory;
-            outFilePath += inFileName;
-            outFilePath += options.getOutFileSuffix();
-
-            if ( !options.quietMode() ) {
+            if (!options.forceStdout()){
+                outFilePath = outDirectory;
+                outFilePath += inFileName;
+                outFilePath += options.getOutFileSuffix();
+            }
+            if ( !options.quietMode() &&  !options.forceStdout() ) {
                 if ( options.printProgress() ) {
                     printProgressBar ( fileCount, i+1 );
                 } else {
                     printCurrentAction ( outFilePath, fileCount, i+1, fileCountWidth );
                 }
             }
-        } else {
+        } else if (!options.forceStdout()) {
             outFilePath = options.getSingleOutFilename();
             if ( outFilePath.size() && outFilePath==options.getSingleInFilename() ) {
-                cerr 	<< "highlight: Output path equals input path: \""
-                        << outFilePath << "\".\n";
+                cerr << "highlight: Output path equals input path: \""
+                     << outFilePath << "\".\n";
                 initError = true;
                 break;
             }
-
         }
 
         if ( options.useFNamesAsAnchors() ) {
@@ -620,7 +620,6 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
                               inFileList[i]:options.getDocumentTitle() );
 
         generator->setKeyWordCase ( options.getKeywordCase() );
-
         highlight::ParseError error = generator->generateFile ( inFileList[i], outFilePath );
 
         if ( error==highlight::BAD_INPUT ) {
