@@ -2,7 +2,7 @@
                                mainwindow.cpp
                              -------------------
     begin                : Mo 16.03.2009
-    copyright            : (C) 2009-2015 by Andre Simon
+    copyright            : (C) 2009-2017 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -42,12 +42,16 @@ MainWindow::MainWindow(QWidget *parent)
     this->setWindowTitle(QString("Highlight %1").arg( HIGHLIGHT_VERSION));
 
     // Read file open filter
-#ifdef DATA_DIR
-    QFile filterDef(QString(DATA_DIR) + "/gui_files/ext/fileopenfilter.conf");
+#ifdef Q_OS_OSX
+    QFile filterDef(QCoreApplication::applicationDirPath()+"/../Resources/gui_files/ext/fileopenfilter.conf");
 #else
+    #ifdef DATA_DIR
+    QFile filterDef(QString(DATA_DIR) + "/gui_files/ext/fileopenfilter.conf");
+    #else
     QFile filterDef(QDir::currentPath()+"/gui_files/ext/fileopenfilter.conf");
+    #endif
 #endif
-
+    
     QRegExp rx("(\\S+)\\s?\\(\\*\\.([\\w\\d]+)");
 
     if (filterDef.open(QIODevice::ReadOnly | QIODevice::Text)) {
@@ -67,14 +71,19 @@ MainWindow::MainWindow(QWidget *parent)
     } else {
         fileOpenFilter="All files (*)";
     }
-    
+
     // fill themes combo
-#ifdef DATA_DIR
-    QDir themesDir(QString(DATA_DIR) + "/themes");
+
+#ifdef Q_OS_OSX
+    QDir themesDir(QCoreApplication::applicationDirPath() + "/../Resources/themes");
 #else
+    #ifdef DATA_DIR
+    QDir themesDir(QString(DATA_DIR) + "/themes");
+    #else
     QDir themesDir(QDir::currentPath()+"/themes");
+    #endif
 #endif
-    
+
     QStringList themes = themesDir.entryList(QStringList("*.theme"), QDir::Files, QDir::Name);
     for (QStringList::const_iterator constIterator = themes.constBegin();
             constIterator != themes.constEnd(); ++constIterator) {
@@ -95,7 +104,7 @@ MainWindow::MainWindow(QWidget *parent)
     }
 
     //avoid ugly buttons in MacOS
-    #ifndef Q_OS_MACOS
+    #ifndef Q_OS_OSX
         ui->pbPluginReadFilePath->setMaximumWidth(30);
         ui->pbOutputDest->setMaximumWidth(30);
         ui->pbHTMLChooseStyleIncFile->setMaximumWidth(30);
@@ -208,7 +217,6 @@ void MainWindow::addToView(const QStringList& list, QListWidget* listWidget, con
         listItem->setData(Qt::UserRole, *constIterator);
         if (checkable) listItem->setCheckState( Qt::Unchecked);
         listWidget->addItem(listItem );
-
     }
 }
 
@@ -239,7 +247,6 @@ void MainWindow::writeSettings()
 
     QStringList plugins;
     for (int i=0; i<ui->lvPluginScripts->count(); i++) {
-        //plugins<<ui->lvPluginScripts->item(i)->text();
         plugins<<ui->lvPluginScripts->item(i)->data(Qt::UserRole).toString();
     }
 
@@ -254,8 +261,7 @@ void MainWindow::writeSettings()
                       inFiles);
     settings.setValue(ui->lvPluginScripts->property(name).toString(),
                       plugins);
-    settings.setValue("selectedPlugins",
-                      selectedPlugins);
+    settings.setValue("selectedPlugins", selectedPlugins);
     settings.setValue(ui->leOutputDest->property(name).toString(),
                       ui->leOutputDest->text());
     settings.setValue(ui->cbWrite2Src->property(name).toString(),
@@ -461,7 +467,6 @@ void MainWindow::readSettings()
     ui->sbLineNoWidth->setValue(settings.value(ui->sbLineNoWidth->property(name).toString(), 2).toInt());
     ui->sbLineNoStart->setValue(settings.value(ui->sbLineNoStart->property(name).toString(), 1).toInt());
 
-
     settings.endGroup();
 }
 
@@ -469,10 +474,14 @@ bool MainWindow::loadFileTypeConfig(StringMap* extMap, StringMap* shebangMap)
 {
     if (!extMap || !shebangMap) return false;
 
-#ifdef CONFIG_DIR
-    QString filetypesPath = QDir::toNativeSeparators(QString("%1/filetypes.conf").arg(CONFIG_DIR));
+#ifdef Q_OS_OSX
+    QString filetypesPath = QDir::toNativeSeparators(QString("%1/../Resources/filetypes.conf").arg(QCoreApplication::applicationDirPath()));
 #else
+    #ifdef CONFIG_DIR
+    QString filetypesPath = QDir::toNativeSeparators(QString("%1/filetypes.conf").arg(CONFIG_DIR));
+    #else
     QString filetypesPath = QDir::toNativeSeparators(QString("%1/filetypes.conf").arg(QDir::currentPath()));
+    #endif        
 #endif
 
     try {
@@ -508,7 +517,6 @@ string MainWindow::analyzeFile(const string& file)
     getline (inFile, firstLine);
     StringMap::iterator it;
 
-
     boost::xpressive::sregex rex;
     boost::xpressive::smatch what;
     for ( it=shebangs.begin(); it!=shebangs.end(); it++ ) {
@@ -551,9 +559,9 @@ void MainWindow::on_action_About_Highlight_triggered()
     QMessageBox::about( this, "About Highlight",
                         QString("Highlight is a code to formatted text converter.\n\n"
                                 "Highlight GUI %1\n"
-                                "(C) 2002-2016 Andre Simon <andre.simon1 at gmx.de>\n\n"
+                                "(C) 2002-2017 Andre Simon <andre.simon1 at gmx.de>\n\n"
                                 "Artistic Style Classes\n(C) 1998-2002 Tal Davidson\n"
-                                "(C) 2006-2014 Jim Pattee <jimp03 at email.com>\n\n"
+                                "(C) 2006-2016 Jim Pattee <jimp03 at email.com>\n\n"
                                 "Diluculum Lua wrapper\n"
                                 "(C) 2005-2013 by Leandro Motta Barros\n\n"
                                 "Built with Qt version %2\n\n"
@@ -565,7 +573,6 @@ void MainWindow::on_action_About_Highlight_triggered()
 
 highlight::OutputType MainWindow::getOutputType()
 {
-
     switch (ui->comboFormat->currentIndex()) {
     case 0:
         return highlight::HTML;
@@ -678,14 +685,19 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
     generator->setPrintZeroes(ui->cbPadZeroes->isEnabled() && ui->cbPadZeroes->isChecked());
     generator->setPluginParameter(ui->lePluginReadFilePath->text().toStdString());
 
-#ifdef DATA_DIR
+#ifdef Q_OS_OSX
+    QString themePath = QString("%1/../Resources/themes/%2.theme").arg(
+                            QCoreApplication::applicationDirPath()).arg(ui->comboTheme->currentText());
+#else
+    #ifdef DATA_DIR
     QString themePath = QString("%1themes/%2.theme").arg(
                             DATA_DIR).arg(ui->comboTheme->currentText());
-#else
+    #else
     QString themePath = QString("%1/themes/%2.theme").arg(
                             QDir::currentPath()).arg(ui->comboTheme->currentText());
+    #endif
 #endif
-
+    
     for (int i=0; i<ui->lvPluginScripts->count(); i++) {
         if (ui->lvPluginScripts->item(i)->checkState()==Qt::Checked) {
             if (!generator->initPluginScript(ui->lvPluginScripts->item(i)->data(Qt::UserRole).toString().toStdString()) ) {
@@ -741,7 +753,6 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
 
     if (ui->cbReformat->isChecked()) {
         generator->initIndentationScheme(ui->comboReformat->currentText().toLower().toStdString());
-
     }
 }
 
@@ -752,7 +763,6 @@ highlight::WrapMode MainWindow::getWrappingStyle()
     return (ui->cbWrapping->isChecked())?highlight::WRAP_DEFAULT:highlight::WRAP_DISABLED;
 }
 
-
 void MainWindow::on_pbStartConversion_clicked()
 {
     if (!ui->lvInputFiles->count()) return;
@@ -827,14 +837,19 @@ void MainWindow::on_pbStartConversion_clicked()
 
         statusBar()->showMessage(tr("Processing %1 (%2/%3)").arg(inFilePath).arg(i+1).arg(ui->lvInputFiles->count()));
 
-#ifdef DATA_DIR
-        langDefPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(DATA_DIR).arg(
+#ifdef Q_OS_OSX
+        langDefPath = QDir::toNativeSeparators(QString("%1/../Resources/langDefs/%2.lang").arg(QCoreApplication::applicationDirPath()).arg(
                 QString::fromStdString(getFileType(getFileSuffix(currentFile), currentFile))));
 #else
+    #ifdef DATA_DIR
+        langDefPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(DATA_DIR).arg(
+                QString::fromStdString(getFileType(getFileSuffix(currentFile), currentFile))));
+    #else
         langDefPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(QDir::currentPath()).arg(
                 QString::fromStdString(getFileType(getFileSuffix(currentFile), currentFile))));
+    #endif
 #endif
-
+        
         loadRes=generator->loadLanguage(langDefPath.toStdString());
         if (loadRes==highlight::LOAD_FAILED_REGEX) {
             QMessageBox::warning(this, tr("Language definition error"),
@@ -903,16 +918,6 @@ void MainWindow::on_pbStartConversion_clicked()
         }
     }
 
-    // write external Stylesheet (one for all output files)
-    /*
-    if (!ui->cbWrite2Src->isChecked() && cbEmbed && leStyleFile && !cbEmbed->isChecked()) {
-        QString stylePath=QFileInfo(ui->leOutputDest->text(), leStyleFile->text()).absoluteFilePath();
-        bool styleFileOK=generator -> printExternalStyle(QDir::toNativeSeparators(stylePath).toStdString());
-        if (!styleFileOK) {
-            outputErrors.append(stylePath);
-        }
-    }*/
-
     // write HTML index file
     if (    (outType==highlight::HTML || outType==highlight::XHTML)
             && ui->cbHTMLIndex->isChecked() && !ui->cbWrite2Src->isChecked()) {
@@ -985,12 +990,17 @@ void MainWindow::highlight2Clipboard(bool getDataFromCP)
         generator->setTitle(inFileName.toStdString());
     }
 
-#ifdef DATA_DIR
+#ifdef Q_OS_OSX
+    QString langPath = QDir::toNativeSeparators(QString("%1/../Resources//langDefs/%2.lang").arg(
+                           QCoreApplication::applicationDirPath()).arg(QString::fromStdString(suffix)));
+#else
+    #ifdef DATA_DIR
     QString langPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(
                            DATA_DIR).arg(QString::fromStdString(suffix)));
-#else
+    #else
     QString langPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(
                            QDir::currentPath()).arg(QString::fromStdString(suffix)));
+    #endif
 #endif
 
     if ( generator->loadLanguage(langPath.toStdString()) != highlight::LOAD_FAILED) {
@@ -1085,7 +1095,6 @@ void MainWindow::plausibility()
 
 void MainWindow::updatePreview()
 {
-
     //toggle input source flag if file is selcetd or clipboard is pasted
     if (sender()== ui->pbPasteFromCB|| sender()==ui->lvInputFiles) {
         getDataFromCP = sender()==ui->pbPasteFromCB;
@@ -1094,7 +1103,6 @@ void MainWindow::updatePreview()
     if ((!getDataFromCP && NULL==ui->lvInputFiles->currentItem())
             || (getDataFromCP && savedClipboardContent.isEmpty())) return;
 
-
     int vScroll = ui->browserPreview->verticalScrollBar()->value();
     int hScroll = ui->browserPreview->horizontalScrollBar()->value();
     this->setCursor(Qt::WaitCursor);
@@ -1108,6 +1116,7 @@ void MainWindow::updatePreview()
 
     string suffix;
     QString previewInputPath = (getDataFromCP) ? "" : ui->lvInputFiles->currentItem()->data(Qt::UserRole).toString();
+    QString croppedName = QFileInfo(previewInputPath).fileName();
 
     if (getDataFromCP) {
         suffix= getFileType((ui->comboSelectSyntax->itemData(ui->comboSelectSyntax->currentIndex())).toString().toStdString(),"");
@@ -1115,18 +1124,24 @@ void MainWindow::updatePreview()
         string currentFile = previewInputPath.toStdString();
         suffix = getFileType(getFileSuffix(currentFile), currentFile);
     }
-#ifdef DATA_DIR
+    
+#ifdef Q_OS_OSX
+    QString langPath = QDir::toNativeSeparators(QString("%1/../Resources//langDefs/%2.lang").arg(
+                           QCoreApplication::applicationDirPath()).arg(QString::fromStdString(suffix)));
+#else
+    #ifdef DATA_DIR
     QString langPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(
                            DATA_DIR).arg(QString::fromStdString(suffix)));
-#else
+    #else
     QString langPath = QDir::toNativeSeparators(QString("%1/langDefs/%2.lang").arg(
                            QDir::currentPath()).arg(QString::fromStdString(suffix)));
+    #endif
 #endif
 
     if ( pwgenerator.loadLanguage(langPath.toStdString()) != highlight::LOAD_FAILED) {
 
         ui->lbPreview->setText(tr("Preview (%1):").arg(
-                                   (getDataFromCP)?tr("clipboard data"):previewInputPath) );
+                                   (getDataFromCP)?tr("clipboard data"):croppedName) );
 
         statusBar()->showMessage(tr("Current syntax: %1").arg(QString::fromStdString(pwgenerator.getSyntaxDescription())));
         QString previewData;
@@ -1145,10 +1160,9 @@ void MainWindow::updatePreview()
                 previewData= QString::fromStdString( pwgenerator.generateStringFromFile(previewInputPath.toStdString()));
             }
         }
-
         ui->browserPreview->setHtml(previewData);
     } else {
-        statusBar()->showMessage(tr("Preview of \"%1\" not possible.").arg((getDataFromCP)?tr("clipboard data"):previewInputPath));
+        statusBar()->showMessage(tr("Preview of \"%1\" not possible.").arg((getDataFromCP)?tr("clipboard data"):croppedName));
     }
     ui->browserPreview->verticalScrollBar()->setValue(vScroll);
     ui->browserPreview->horizontalScrollBar()->setValue(hScroll);
@@ -1219,11 +1233,8 @@ void MainWindow::dropEvent(QDropEvent *event)
     if (mimeData && mimeData->hasUrls()) {
         QList<QUrl> urlList = mimeData->urls();
         QStringList localURLs;
-
         for (int i = 0; i < urlList.size(); ++i) {
-
             localURLs << urlList.at(i).toLocalFile();
-
         }
         addToView(localURLs, ui->lvInputFiles);
     }
@@ -1262,10 +1273,14 @@ void MainWindow::on_pbCopyToCP_clicked()
 
 void MainWindow::on_pbSelectPlugin_clicked()
 {
-#ifdef DATA_DIR
-    QString pluginsPath = QDir::toNativeSeparators(QString("%1/plugins").arg(DATA_DIR));
+#ifdef Q_OS_OSX
+    QString pluginsPath = QString("%1/../Resources/plugins").arg(QCoreApplication::applicationDirPath());
 #else
+    #ifdef DATA_DIR
+    QString pluginsPath = QDir::toNativeSeparators(QString("%1/plugins").arg(DATA_DIR));
+    #else
     QString pluginsPath = QDir::toNativeSeparators(QString("%1/plugins").arg(QDir::currentPath()));
+    #endif
 #endif
 
     QStringList files = QFileDialog::getOpenFileNames(
